NCurses determines the presence of the <stdbool.h> header during its
own build time but the result is used in a public header <curses.h>.
It cannot be assumed that the application building against this public
header <curses.h> also uses the same compiler NCurses was built with.
Hence the public header <curses.h> has to perform an own in-place check
for <stdbool.h>. This way NCurses can be build with OpenPKG's GCC 3.x
while an application could build against the provided <curses.h> with an
arbitrary C compiler (usually a non-GCC 3.x vendor compiler!).

Index: include/curses.h.in
--- include/curses.h.in.orig	2004-02-22 09:36:58.000000000 +0100
+++ include/curses.h.in	2004-02-22 09:37:14.000000000 +0100
@@ -61,7 +61,11 @@
  * User-definable tweak to disable the include of <stdbool.h>.
  */
 #ifndef NCURSES_ENABLE_STDBOOL_H
-#define NCURSES_ENABLE_STDBOOL_H @cf_cv_header_stdbool_h@
+#if defined(__STDC__) && (__STDC_VERSION__ >= 199901L) && !defined(__osf__)
+#define NCURSES_ENABLE_STDBOOL_H 1
+#else
+#define NCURSES_ENABLE_STDBOOL_H 0
+#endif
 #endif
 
 /*
Index: ncurses/Makefile.in
--- ncurses/Makefile.in.orig	Wed Dec 22 13:02:27 2004
+++ ncurses/Makefile.in	Wed Dec 22 13:02:30 2004
@@ -273,7 +273,8 @@
 	@ECHO_LINK@ $(CC) -o $@ $(CFLAGS_DEFAULT) -DHASHDEBUG $(serial)/hashmap.c $(TEST_LDFLAGS)
 
 lib_mvcur$x : $(serial)/lib_mvcur.c $(TEST_DEPS) \
-		../@DFT_OBJ_SUBDIR@/dump_entry$o
+		../@DFT_OBJ_SUBDIR@/dump_entry$o \
+		../@DFT_OBJ_SUBDIR@/comp_parse$o
 	@ECHO_LINK@ $(CC) -o $@ $(CFLAGS_DEFAULT) -DNCURSES_TEST -I$(serial)/../../progs $(serial)/lib_mvcur.c ../@DFT_OBJ_SUBDIR@/dump_entry$o $(TEST_LDFLAGS)
 
 link_test$x : link_test.c $(TEST_DEPS) \
Index: progs/Makefile.in
--- progs/Makefile.in.orig	Sat Nov  1 23:45:57 2003
+++ progs/Makefile.in	Wed Dec 22 13:04:07 2004
@@ -192,7 +192,8 @@
 
 DEPS_TIC = \
 	$(MODEL)/tic$o \
-	$(MODEL)/dump_entry$o
+	$(MODEL)/dump_entry$o \
+	$(MODEL)/comp_parse$o
 
 tic$x: $(DEPS_TIC) $(DEPS_CURSES) transform.h
 	@ECHO_LINK@ $(LINK) $(DEPS_TIC) $(LDFLAGS_DEFAULT) -o $@
@@ -211,14 +212,16 @@
 	@ECHO_LINK@ $(LINK) $(DEPS_CLEAR) $(LDFLAGS_DEFAULT) -o $@
 
 DEPS_TPUT = \
-	$(MODEL)/tput$o
+	$(MODEL)/tput$o \
+	$(MODEL)/lib_tparm$o
 
 tput$x: $(DEPS_TPUT) $(DEPS_CURSES) transform.h
 	@ECHO_LINK@ $(LINK) $(DEPS_TPUT) $(LDFLAGS_DEFAULT) -o $@
 
 DEPS_INFOCMP = \
 	$(MODEL)/infocmp$o \
-	$(MODEL)/dump_entry$o
+	$(MODEL)/dump_entry$o \
+	$(MODEL)/comp_parse$o
 
 infocmp$x: $(DEPS_INFOCMP) $(DEPS_CURSES)
 	@ECHO_LINK@ $(LINK) $(DEPS_INFOCMP) $(LDFLAGS_DEFAULT) -o $@
Index: test/programs
--- test/programs.orig	2006-06-18 09:10:51 +0200
+++ test/programs	2006-06-18 09:13:14 +0200
@@ -36,7 +36,7 @@
 cardfile	$(LDFLAGS_DEFAULT)	$(LOCAL_LIBS)	cardfile
 color_set	$(LDFLAGS_CURSES)	$(LOCAL_LIBS)	color_set
 demo_altkeys	$(LDFLAGS_CURSES)	$(LOCAL_LIBS)	demo_altkeys
-demo_defkey	$(LDFLAGS_CURSES)	$(LOCAL_LIBS)	demo_defkey
+demo_defkey	$(LDFLAGS_CURSES)	$(LOCAL_LIBS)	demo_defkey key_defined
 demo_forms	$(LDFLAGS_DEFAULT)	$(LOCAL_LIBS)	demo_forms edit_field
 demo_keyok	$(LDFLAGS_CURSES)	$(LOCAL_LIBS)	demo_keyok
 demo_menus	$(LDFLAGS_DEFAULT)	$(LOCAL_LIBS)	demo_menus
